@@ -14,10 +14,14 @@ def main():
     cfg.read_string(resources.read_text("gitvars", "config.txt"))
     gitlab_project = cfg.get("project", "gitlab_project")
     var_prefix = cfg.get("project", "var_prefix")
+    exclude_keys_str = cfg.get("project", "exclude_keys")
+    exclude_keys = []
+    if(exclude_keys_str):
+        exclude_keys = exclude_keys_str.split(",")
 
     # If an article ID is given, show the article
     if len(sys.argv) > 1:
-        cicd_vars = readvars._read(sys.argv[1], gitlab_project, var_prefix)
+        cicd_vars = readvars._read(sys.argv[1], gitlab_project, var_prefix, exclude_keys)
         printvars._prettyprint(cicd_vars)
 
     # If no ID is given, show a list of all articles
